
# Type: category




URI: [https://example.com/test62/category](https://example.com/test62/category)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>1..*</sub> [IriType](types/IriType.md)

## Parents


## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | rdfs:subClassOf |

